@@ -41,5 +41,5 @@ class Schema:
         self._parts = parts
         return self
 
-    def to_json(self):
+    def toJSON(self):
         return self.__str__()
